import * as i0 from '@angular/core';
import { Injectable, Component, Input, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';

class NgxLoadingSpinnerService {
    /**
     * Creates an instance of NgxLoadingSpinnerService.
     * @memberof NgxLoadingSpinnerService
     */
    constructor() {
        /**
           * @description spinners BehaviorSubject
           * @memberof NgxLoadingSpinnerService
           */
        this.spinnerSubject = new BehaviorSubject(false);
    }
    /**
     * To show spinner
     * @memberof NgxLoadingSpinnerService
     */
    show() {
        this.spinnerSubject.next(true);
    }
    /**
     * To hide spinner
     * @memberof NgxLoadingSpinnerService
     */
    hide() {
        this.spinnerSubject.next(false);
    }
    getMessage() {
        return this.spinnerSubject.asObservable();
    }
}
NgxLoadingSpinnerService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: NgxLoadingSpinnerService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
NgxLoadingSpinnerService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: NgxLoadingSpinnerService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: NgxLoadingSpinnerService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class NgxLoadingSpinnerComponent {
    /**
     * Constructor
     * @param spinnerService Spinner Service
     * @memberof NgxLoadingSpinnerComponent
     */
    constructor(spinnerService) {
        this.spinnerService = spinnerService;
        /**
          * @description Default loading spinner template
          * @memberof NgxLoadingSpinnerComponent
          */
        this._template = `<div class="lds-roller"><div></div><div></div><div></div><div></div><div></div><div></div><div></div><div></div></div>`;
        /**
         * @description Loading text
         * @memberof NgxLoadingSpinnerComponent
         */
        this._loadingText = '';
        /**
         * @description Defines threhold for not to diplay if time is less than 500ms
         * @memberof NgxLoadingSpinnerComponent
         */
        this._threshold = 500;
        /**
         * @description Defines timeout to hide after time 5000ms
         * @memberof NgxLoadingSpinnerComponent
         */
        this._timeout = 0;
        /**
         * @description Defines z-index property of the loading text
         * @memberof NgxLoadingSpinnerComponent
         */
        this._zIndex = 9999;
        /**
         * Subscription
         * @memberof NgxLoadingSpinnerComponent
         */
        this.subscription = {};
        /**
         * @description Show/hide spinner
         * @memberof NgxLoadingSpinnerComponent
         */
        this.showSpinner = false;
        this.createServiceSubscription();
    }
    /**
     * @description Sets z-index for input text
     * @memberof NgxLoadingSpinnerComponent
     */
    set zIndex(value) {
        this._zIndex = value;
    }
    /**
     * @description returns z-index for input text
     * @readonly
     * @memberof NgxLoadingSpinnerComponent
     */
    get zIndex() {
        return this._zIndex;
    }
    /**
     * @description Accepts custom template
     * @memberof NgxLoadingSpinnerComponent
     */
    set template(value) {
        this._template = value;
    }
    /**
     * @description Gives the current template
     * @readonly
     * @memberof NgxLoadingSpinnerComponent
     */
    get template() {
        return this._template;
    }
    /**
     * @description Accepts loading text string
     * @memberof NgxLoadingSpinnerComponent
     */
    set loadingText(value) {
        this._loadingText = value;
    }
    /**
     * @description Gives loading text
     * @readonly
     * @memberof NgxLoadingSpinnerComponent
     */
    get loadingText() {
        return this._loadingText;
    }
    /**
     * @description Accepts external threshold
     * @memberof NgxLoadingSpinnerComponent
     */
    set threshold(value) {
        this._threshold = value;
    }
    /**
     * @description
     * @readonly
     * @memberof NgxLoadingSpinnerComponent
     */
    get threshold() {
        return this._threshold;
    }
    /**
     * @description Accepts external timeout
     * @memberof NgxLoadingSpinnerComponent
     */
    set timeout(value) {
        this._timeout = value;
    }
    /**
     * @description
     * @readonly
     * @memberof NgxLoadingSpinnerComponent
     */
    get timeout() {
        return this._timeout;
    }
    ngOnInit() { }
    /**
     * Destroy function
     * @memberof NgxLoadingSpinnerComponent
     */
    ngOnDestroy() {
        this.subscription.unsubscribe();
    }
    /**
     * Create service subscription
     * @memberof NgxLoadingSpinnerComponent
     */
    createServiceSubscription() {
        let thresholdTimer;
        let timeoutTimer;
        this.subscription =
            this.spinnerService.getMessage().subscribe(show => {
                if (show) {
                    if (thresholdTimer) {
                        return;
                    }
                    thresholdTimer = setTimeout(() => {
                        thresholdTimer = null;
                        this.showSpinner = show;
                        if (this.timeout !== 0) {
                            timeoutTimer = setTimeout(() => {
                                timeoutTimer = null;
                                this.showSpinner = false;
                            }, this.timeout);
                        }
                    }, this.threshold);
                }
                else {
                    if (thresholdTimer) {
                        clearTimeout(thresholdTimer);
                        thresholdTimer = null;
                    }
                    if (timeoutTimer) {
                        clearTimeout(timeoutTimer);
                    }
                    timeoutTimer = null;
                    this.showSpinner = false;
                }
            });
    }
}
NgxLoadingSpinnerComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: NgxLoadingSpinnerComponent, deps: [{ token: NgxLoadingSpinnerService }], target: i0.ɵɵFactoryTarget.Component });
NgxLoadingSpinnerComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.0.2", type: NgxLoadingSpinnerComponent, selector: "lib-ngx-loading-spinner", inputs: { zIndex: "zIndex", template: "template", loadingText: "loadingText", threshold: "threshold", timeout: "timeout" }, ngImport: i0, template: "<div #spinnerContainer [class]=\"showSpinner ? 'visible spinner center' : 'hidden spinner center'\"\n  [innerHTML]=\"template\">\n</div>\n<div id=\"loading-spinner-text\" class=\"loading-spinner-text\" [style.zIndex]=\"zIndex\"\n  [class]=\"showSpinner ? 'visible loading-text' : 'hidden loading-text'\"> {{loadingText}} </div>\n", styles: [".spinner{position:fixed;padding:0;top:0;left:0;height:100%;width:100%;z-index:9998;background:#000;opacity:.6;transition:opacity .3s linear}.center{margin:auto;width:100%}.loading-text{position:fixed;top:0;width:100%;height:100%;left:0;padding:33% 0 0;margin:0;color:#fff;font-family:sans-serif;background:transparent;text-align:center}.spinner img{position:fixed;padding:0;z-index:10;background:#000;opacity:.6;transition:opacity .3s linear}.hidden{visibility:hidden;opacity:0;transition:visibility 0s .3s,opacity .3s linear}.visible{visibility:visible}.lds-roller{display:inline-block;position:relative;width:64px;height:64px;left:48%;top:47%}.lds-roller div{animation:lds-roller 1.2s cubic-bezier(.5,0,.5,1) infinite;transform-origin:32px 32px}.lds-roller div:after{content:\" \";display:block;position:absolute;width:6px;height:6px;border-radius:50%;background:#fff;margin:-3px 0 0 -3px}.lds-roller div:nth-child(1){animation-delay:-36ms}.lds-roller div:nth-child(1):after{top:50px;left:50px}.lds-roller div:nth-child(2){animation-delay:-72ms}.lds-roller div:nth-child(2):after{top:54px;left:45px}.lds-roller div:nth-child(3){animation-delay:-.108s}.lds-roller div:nth-child(3):after{top:57px;left:39px}.lds-roller div:nth-child(4){animation-delay:-.144s}.lds-roller div:nth-child(4):after{top:58px;left:32px}.lds-roller div:nth-child(5){animation-delay:-.18s}.lds-roller div:nth-child(5):after{top:57px;left:25px}.lds-roller div:nth-child(6){animation-delay:-.216s}.lds-roller div:nth-child(6):after{top:54px;left:19px}.lds-roller div:nth-child(7){animation-delay:-.252s}.lds-roller div:nth-child(7):after{top:50px;left:14px}.lds-roller div:nth-child(8){animation-delay:-.288s}.lds-roller div:nth-child(8):after{top:45px;left:10px}@keyframes lds-roller{0%{transform:rotate(0)}to{transform:rotate(360deg)}}#loading-spinner-text,.loading-spinner-text{font-size:26px}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: NgxLoadingSpinnerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-ngx-loading-spinner', template: "<div #spinnerContainer [class]=\"showSpinner ? 'visible spinner center' : 'hidden spinner center'\"\n  [innerHTML]=\"template\">\n</div>\n<div id=\"loading-spinner-text\" class=\"loading-spinner-text\" [style.zIndex]=\"zIndex\"\n  [class]=\"showSpinner ? 'visible loading-text' : 'hidden loading-text'\"> {{loadingText}} </div>\n", styles: [".spinner{position:fixed;padding:0;top:0;left:0;height:100%;width:100%;z-index:9998;background:#000;opacity:.6;transition:opacity .3s linear}.center{margin:auto;width:100%}.loading-text{position:fixed;top:0;width:100%;height:100%;left:0;padding:33% 0 0;margin:0;color:#fff;font-family:sans-serif;background:transparent;text-align:center}.spinner img{position:fixed;padding:0;z-index:10;background:#000;opacity:.6;transition:opacity .3s linear}.hidden{visibility:hidden;opacity:0;transition:visibility 0s .3s,opacity .3s linear}.visible{visibility:visible}.lds-roller{display:inline-block;position:relative;width:64px;height:64px;left:48%;top:47%}.lds-roller div{animation:lds-roller 1.2s cubic-bezier(.5,0,.5,1) infinite;transform-origin:32px 32px}.lds-roller div:after{content:\" \";display:block;position:absolute;width:6px;height:6px;border-radius:50%;background:#fff;margin:-3px 0 0 -3px}.lds-roller div:nth-child(1){animation-delay:-36ms}.lds-roller div:nth-child(1):after{top:50px;left:50px}.lds-roller div:nth-child(2){animation-delay:-72ms}.lds-roller div:nth-child(2):after{top:54px;left:45px}.lds-roller div:nth-child(3){animation-delay:-.108s}.lds-roller div:nth-child(3):after{top:57px;left:39px}.lds-roller div:nth-child(4){animation-delay:-.144s}.lds-roller div:nth-child(4):after{top:58px;left:32px}.lds-roller div:nth-child(5){animation-delay:-.18s}.lds-roller div:nth-child(5):after{top:57px;left:25px}.lds-roller div:nth-child(6){animation-delay:-.216s}.lds-roller div:nth-child(6):after{top:54px;left:19px}.lds-roller div:nth-child(7){animation-delay:-.252s}.lds-roller div:nth-child(7):after{top:50px;left:14px}.lds-roller div:nth-child(8){animation-delay:-.288s}.lds-roller div:nth-child(8):after{top:45px;left:10px}@keyframes lds-roller{0%{transform:rotate(0)}to{transform:rotate(360deg)}}#loading-spinner-text,.loading-spinner-text{font-size:26px}\n"] }]
        }], ctorParameters: function () { return [{ type: NgxLoadingSpinnerService }]; }, propDecorators: { zIndex: [{
                type: Input
            }], template: [{
                type: Input
            }], loadingText: [{
                type: Input
            }], threshold: [{
                type: Input
            }], timeout: [{
                type: Input
            }] } });

class NgxLoadingSpinnerModule {
    static forRoot() {
        return {
            ngModule: NgxLoadingSpinnerModule,
            providers: [NgxLoadingSpinnerService]
        };
    }
}
NgxLoadingSpinnerModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: NgxLoadingSpinnerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxLoadingSpinnerModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: NgxLoadingSpinnerModule, declarations: [NgxLoadingSpinnerComponent], exports: [NgxLoadingSpinnerComponent] });
NgxLoadingSpinnerModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: NgxLoadingSpinnerModule, imports: [[]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.0.2", ngImport: i0, type: NgxLoadingSpinnerModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgxLoadingSpinnerComponent
                    ],
                    imports: [],
                    exports: [
                        NgxLoadingSpinnerComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-loading-spinner
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxLoadingSpinnerComponent, NgxLoadingSpinnerModule, NgxLoadingSpinnerService };
